@@ -461,7 +461,8 @@ Useful keys:
 				    (list (symbol-name (car dependency))))
 				  riece-addon-modules)
 			  (lambda (pointer)
-			    (not (get (car pointer) 'riece-addon-insinuated)))
+			    (not (get (intern-soft (car pointer))
+				      'riece-addon-insinuated)))
 			  t)))))
   (riece-insinuate-addon addon 'ask)
   (when (eq major-mode 'riece-addon-list-mode)
@@ -479,7 +480,8 @@ Useful keys:
 				    (list (symbol-name (car dependency))))
 				  riece-addon-dependencies)
 			  (lambda (pointer)
-			    (get (car pointer) 'riece-addon-insinuated))
+			    (get (intern-soft (car pointer))
+				 'riece-addon-insinuated))
 			  t)))))
   (riece-uninstall-addon addon t)
   (when (eq major-mode 'riece-addon-list-mode)
@@ -497,7 +499,8 @@ Useful keys:
 				    (list (symbol-name (car dependency))))
 				  riece-addon-dependencies)
 			  (lambda (pointer)
-			    (get (car pointer) 'riece-addon-insinuated))
+			    (get (intern-soft (car pointer))
+				 'riece-addon-insinuated))
 			  t)))))
   (riece-uninstall-addon addon t)
   (if (get addon 'riece-addon-not-unloadable)
