@@ -1,4 +1,4 @@
-;;; riece-lsdb.el --- interface to LSDB
+;;; riece-lsdb.el --- help register nicknames in LSDB rolodex program
 ;; Copyright (C) 1998-2003 Daiki Ueno
 
 ;; Author: Daiki Ueno <ueno@unixuser.org>
@@ -19,17 +19,17 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
 
-;; To use, add the following line to your ~/.riece/init.el:
-;; (add-to-list 'riece-addons 'riece-lsdb)
+;; NOTE: This is an add-on module for Riece.
 
 ;;; Code:
 
 (require 'riece-identity)
+(require 'riece-misc)
 
 (eval-when-compile
   (autoload 'lsdb-maybe-load-hash-tables "lsdb")
@@ -43,6 +43,9 @@
 
 (defvar riece-lsdb-cache nil)
 
+(defconst riece-lsdb-description
+  "Help register nicknames in LSDB rolodex program.")
+
 (defun riece-lsdb-update-cache (record)
   (let ((irc (cdr (assq 'irc record))))
     (while irc
@@ -112,6 +115,9 @@
 			  (list (cons 'irc (cons irc old)))))))
 
 (defvar riece-command-mode-map)
+(defvar lsdb-secondary-hash-tables)
+(defvar lsdb-after-update-record-functions)
+(defvar lsdb-after-delete-record-functions)
 (defun riece-lsdb-insinuate ()
   (require 'lsdb)
   (add-to-list 'lsdb-secondary-hash-tables
@@ -119,12 +125,28 @@
   (add-to-list 'lsdb-after-update-record-functions
 	       'riece-lsdb-update-cache)
   (add-to-list 'lsdb-after-delete-record-functions
-	       'riece-lsdb-delete-cache)
+	       'riece-lsdb-delete-cache))
+
+(defun riece-lsdb-uninstall ()
+  (setq lsdb-secondary-hash-tables
+	(delq 'riece-lsdb-cache lsdb-secondary-hash-tables)
+	lsdb-after-update-record-functions
+	(delq 'riece-lsdb-update-cache lsdb-after-update-record-functions)
+	lsdb-after-delete-record-functions
+	(delq 'riece-lsdb-delete-cache lsdb-after-delete-record-functions)))
+
+(defun riece-lsdb-enable ()
   (define-key riece-command-mode-map
     "\C-c\C-ll" 'riece-lsdb-display-records)
   (define-key riece-command-mode-map
     "\C-c\C-la" 'riece-lsdb-add-user))
 
+(defun riece-lsdb-disable ()
+  (define-key riece-command-mode-map
+    "\C-c\C-ll" nil)
+  (define-key riece-command-mode-map
+    "\C-c\C-la" nil))
+
 (provide 'riece-lsdb)
 
 ;;; riece-lsdb.el ends here
