@@ -65,11 +65,6 @@
   :prefix "riece-"
   :group 'riece)
 
-(defcustom riece-use-full-window t
-  "If non-nil, whole Emacs window is used to display dialogue."
-  :type 'boolean
-  :group 'riece-looks)
-
 (defcustom riece-window-center-line -2
   "Line number of center point in window when scrolling.
 If nil, erases the entire frame and then redraws with point in the
@@ -182,6 +177,7 @@ specifying the coding systems for decoding and encoding respectively."
 				 :format "%{%t%}: %v"
 				 (const :tag "" :value :service)
 				 (choice (const :tag "Default" 6667)
+					 integer
 					 string))
 			   (list :inline t :tag "Nickname"
 				 :format "%{%t%}: %v"
@@ -195,23 +191,23 @@ specifying the coding systems for decoding and encoding respectively."
 					 string))
 			   (list :inline t :tag "Username"
 				 :format "%{%t%}: %v"
-				 (const :tag "" :value :host)
+				 (const :tag "" :value :username)
 				 (choice (const :tag "Default" riece-username)
 					 string))
 			   (list :inline t :tag "Password"
 				 :format "%{%t%}: %v"
-				 (const :tag "" :value :host)
+				 (const :tag "" :value :password)
 				 string)
 			   (list :inline t :tag "Function"
 				 :format "%{%t%}: %v"
-				 (const :tag "" :value :host)
+				 (const :tag "" :value :function)
 				 (choice
 				  (const :tag "Default"
 					 riece-default-open-connection-function)
 				  function))
 			   (list :inline t :tag "Coding system"
 				 :format "%{%t%}: %v"
-				 (const :tag "" :value :host)
+				 (const :tag "" :value :coding)
 				 (choice
 				  (const :tag "Default"
 					 riece-default-coding-system)
